@@ -4,6 +4,10 @@
 =end
 
 require "numru/gphys/grib"
+begin
+  require "numru/grib"
+rescue LoadError
+end
 require "numru/gphys/varray"
 
 module NumRu
@@ -16,8 +20,40 @@ module NumRu
 =end
   class VArrayGrib < VArray
 
+    @@GribLib = :gphys_grib
+
+    class << self
+      def use_gphys_grib
+        @@GribLib = :gphys_grib
+        set_grib_lib
+      end
+      def use_rb_grib
+        @@GribLib = :rb_grib
+        set_grib_lib
+      end
+      def grib_lib
+        @@GribLib.dup
+      end
+      def grib
+        @@Grib
+      end
+      def set_grib_lib
+        case @@GribLib
+        when :gphys_grib
+          @@GribDim = GPhys::GribDim
+          @@GribVar = GPhys::GribVar
+          @@Grib = GPhys::Grib
+        when :rb_grib
+          @@GribDim = GribDim
+          @@GribVar = GribVar
+          @@Grib = Grib
+        end
+      end
+    end
+    set_grib_lib
+
     def initialize(aGribVar)
-      if !GribVar===aGribVar && !GribDim===aGribVar
+      if !@@GribVar===aGribVar && !@@GribDim===aGribVar
         raise ArgumentError,"Not a GribVar or GribDim"
       end
       @name = aGribVar.name
@@ -26,9 +62,11 @@ module NumRu
       @ary = aGribVar
       @attr = Attribute.new
       aGribVar.att_names.each{|name|
-        @attr[name] = aGribVar.att(name)
+        val = aGribVar.att(name)
+        val = [val] if val.is_a?(Numeric)
+        @attr[name] = val
       }
-      if GribDim===@ary
+      if @@GribDim===@ary
         class << @ary
           def rank
             return 1
@@ -41,9 +79,9 @@ module NumRu
     end
 
     def inspect
-      if GribVar===@ary
+      if @@GribVar===@ary
         "<'#{@name}' in '#{@ary.file.path}'  [#{@ary.shape.join(", ")}]>"
-      elsif GribDim===@ary
+      elsif @@GribDim===@ary
         "<'#{@name}' in '#{@ary.var.name}'  #{@ary.length}>"
       end
     end
@@ -55,7 +93,7 @@ module NumRu
         v = file.def_var(name)
         dims.length.times{|n|
           d = dims[n]
-          if GribDim===d
+          if @@GribDim===d
             gd = v.def_dim(d.name,n)
             gd.put(d.get)
             d.att_names.each{|name| gd.put_att(name,d.att(name)) }
@@ -80,7 +118,7 @@ module NumRu
       ## < additional class methods > ##
 
       def write(file,vary,dims=nil)
-        Grib===file || raise(ArgumentError,"1st arg: not a Grib")
+        @@Grib===file || raise(ArgumentError,"1st arg: not a Grib")
         VArray===vary || raise(ArgumentError,"2st arg: not a VArray")
         rank = vary.rank
         if !dims
@@ -157,7 +195,7 @@ if $0 == __FILE__
 
   include NumRu
 
-  grib = Grib.open("../../../testdata/T.jan.grib")
+  grib = VArrayGrib.grib.open("../../../testdata/T.jan.grib")
   gv = grib.var("TMP")
 
   va = VArrayGrib.new(gv)
@@ -174,4 +212,10 @@ if $0 == __FILE__
   p va2.shape
   p va2.val
 
+  VArrayGrib.use_rb_grib
+  grib = VArrayGrib.grib.open("../../../testdata/T.jan.grib")
+  p grib.var_names
+  gv = grib.var("t")
+  p gv.val
+
 end
